import { AggregationMapping, FieldMapping } from '@admin-client/reporting-shared';
import { E2EAggregationMappingVerifier } from 'apps/admin-e2e/src/helper/aggregation-mapping/aggregation-mapping.verifier';
import { AggregationMappingFormE2EComponent } from '../../../components/aggregation-mapping/aggregation-mapping-form.e2e.component';
import { AggregationMappingE2EComponent } from '../../../components/aggregation-mapping/aggregation-mapping.e2e.component';
import { E2EAggregationMappingHelper } from '../../../helper/aggregation-mapping/aggregation-mapping.helper';
import { dropCollections } from '../../../support/cypress-helper';
import { exist, notExist } from '../../../support/cypress.util';
import { loginAsDaria } from '../../../support/user-util';

describe('Aggregation Mapping hinzufügen', () => {
  const page: AggregationMappingE2EComponent = new AggregationMappingE2EComponent();
  const form: AggregationMappingFormE2EComponent = new AggregationMappingFormE2EComponent();

  const helper: E2EAggregationMappingHelper = new E2EAggregationMappingHelper();
  const verifier: E2EAggregationMappingVerifier = new E2EAggregationMappingVerifier();

  const fieldMapping0: FieldMapping = {
    sourcePath: '/path/to/source/a',
    targetPath: '/path/to/target/a',
  };

  const fieldMapping1: FieldMapping = {
    sourcePath: '/path/to/source/b',
    targetPath: '/path/to/target/b',
  };

  const aggregationMapping: AggregationMapping = {
    name: 'Aggregation Mapping',
    formIdentifier: {
      formEngineName: 'formEngineName',
      formId: 'formId',
    },
    mappings: [fieldMapping0, fieldMapping1],
  };

  before(() => {
    loginAsDaria();
  });

  after(() => {
    dropCollections();
  });

  it('should show "Weitere Felder auswerten" button', () => {
    helper.openStatistik();

    exist(page.getWeitereFelderAuswertenButton());
  });

  it('should show form after button click', () => {
    page.getWeitereFelderAuswertenButton().click();

    exist(form.getRoot());
  });

  it('should navigate to aggregation mapping on cancel', () => {
    form.getCancelButton().click();

    exist(page.getWeitereFelderAuswertenButton());
  });

  it('should add data field in form', () => {
    page.getWeitereFelderAuswertenButton().click();
    form.getAddFieldButton().click();

    exist(form.getDataFieldInput(1));
  });

  it('should fill out form with two data fields', () => {
    helper.fillFormular(aggregationMapping);

    verifier.verifyForm(aggregationMapping);
  });

  it('should delete data fields', () => {
    form.getDataFieldDeleteButton(0).click();

    notExist(form.getDataFieldInput(1));
  });

  it('should show aggregation mapping in list after save', () => {
    form.getSaveButton().click();

    verifier.verifyAggregationMappingInList(aggregationMapping);
  });
});
