/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { convertToDataTestId } from '../../support/tech.util';

export class AttachmentContainerE2EComponent {
  private readonly multiUploadInput: string = 'multi-file-upload-button';

  private readonly attachmentList: AttachmentListE2EComponent = new AttachmentListE2EComponent();

  public getList(): AttachmentListE2EComponent {
    return this.attachmentList;
  }

  //TODO Rename getMultiUploadButton
  public getUploadInput(): Cypress.Chainable<HTMLElement> {
    return cy.getTestElement(this.multiUploadInput);
  }
}

export class AttachmentListE2EComponent {
  private readonly locatorRoot: string = 'file-list';

  private readonly downloadArchiveButton: string = 'download-archive-file-button';

  public getRoot(): Cypress.Chainable<HTMLElement> {
    return cy.getTestElement(this.locatorRoot);
  }

  public getItem(fileName: string): AttachmentListItemE2EComponent {
    return new AttachmentListItemE2EComponent(fileName);
  }

  public getLoadingOrErrorItem(fileName: string): LoadingErrorAttachmentListeItemE2EComponent {
    return new LoadingErrorAttachmentListeItemE2EComponent(fileName);
  }

  public getDownloadArchiveButton(): Cypress.Chainable<HTMLElement> {
    return this.getRoot().getTestElement(this.downloadArchiveButton);
  }
}

export class AttachmentListItemE2EComponent {
  private readonly deleteButton: string = 'delete-file-button';
  private readonly downloadButton: string = 'download-file-button';

  private locatorRoot: string;

  constructor(private fileName: string) {
    this.locatorRoot = convertToDataTestId(this.fileName) + '-file-item';
  }

  public getRoot(): Cypress.Chainable<HTMLElement> {
    return cy.getTestElement(this.locatorRoot);
  }

  public getDeleteButton(): Cypress.Chainable<HTMLElement> {
    return this.getRoot().findTestElementWithClass(this.deleteButton);
  }

  public getDownloadButton(): Cypress.Chainable<HTMLElement> {
    return this.getRoot().findTestElementWithClass(this.downloadButton);
  }
}

export class LoadingErrorAttachmentListeItemE2EComponent {
  private readonly root: string;
  private readonly attachmentSuffix: string = '-file-upload-list-item-attachment-upload';

  constructor(private fileName: string) {
    this.root = convertToDataTestId(this.fileName) + this.attachmentSuffix;
  }

  public getRoot(): Cypress.Chainable<HTMLElement> {
    return cy.getTestElement(this.root);
  }
}
