/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { replaceAllWhitespaces } from '../../support/tech.util';
import { AttachmentContainerE2EComponent } from '../attachment/attachment.e2e.component';
import { StatusE2EComponent } from './wiedervorlage-status.e2e.component';

export class WiedervorlageInVorgangE2EComponent {
  private readonly frist: string = 'frist';
  private readonly betreff: string = 'betreff';
  private readonly link: string = 'link';
  private readonly expandButton: string = 'expand-button';
  private readonly expandable: string = 'expandable';
  private readonly attachmentContainer: AttachmentContainerE2EComponent = new AttachmentContainerE2EComponent();

  private locatorRoot: string;

  constructor(private betreffIdentificator: string) {
    this.locatorRoot = replaceAllWhitespaces(this.betreffIdentificator, '_');
  }

  public getRoot(): Cypress.Chainable<Element> {
    return cy.getTestElement(this.locatorRoot);
  }

  public getLink(): Cypress.Chainable<Element> {
    return this.getRoot().findTestElementWithClass(this.link);
  }

  public getFrist(): Cypress.Chainable<Element> {
    return this.getRoot().findTestElementWithClass(this.frist);
  }

  public getBetreff(): Cypress.Chainable<Element> {
    return this.getRoot().findTestElementWithClass(this.betreff);
  }

  public getExpandButton(): Cypress.Chainable<Element> {
    return this.getRoot().findTestElementWithClass(this.expandButton);
  }

  public getStatus(): StatusE2EComponent {
    return new StatusE2EComponent(this.locatorRoot);
  }

  public expandItem(): void {
    this.getExpandButton().click();
  }

  public getExpandable(): Cypress.Chainable<Element> {
    return this.getRoot().findTestElementWithClass(this.expandable);
  }

  public getAttachmentContainer(): AttachmentContainerE2EComponent {
    return this.attachmentContainer;
  }
}
