import { generateValidationErrorId, InvalidParam } from '@alfa-client/tech-shared';
import { AsyncPipe } from '@angular/common';
import { Component, Input, OnInit } from '@angular/core';
import { AbstractControl, FormControlStatus, ReactiveFormsModule, UntypedFormGroup } from '@angular/forms';
import { CheckboxEditorComponent, ValidationErrorComponent } from '@ods/component';
import { InfoIconComponent, TooltipDirective } from '@ods/system';
import { isEmpty } from 'lodash-es';
import { map, Observable, of, tap } from 'rxjs';
import { UserFormService } from '../user.formservice';

@Component({
  selector: 'admin-user-form-roles',
  standalone: true,
  imports: [
    CheckboxEditorComponent,
    ReactiveFormsModule,
    TooltipDirective,
    InfoIconComponent,
    ValidationErrorComponent,
    AsyncPipe,
  ],
  templateUrl: './user-form-roles.component.html',
})
export class UserFormRolesComponent implements OnInit {
  @Input() formGroupParent: UntypedFormGroup;

  public invalidParams$: Observable<InvalidParam[]> = of([]);

  public readonly UserFormService = UserFormService;
  public readonly validationErrorId: string = generateValidationErrorId();
  public isValid: boolean = true;

  ngOnInit(): void {
    const control: AbstractControl = this.formGroupParent.controls[UserFormService.CLIENT_ROLES];
    this.invalidParams$ = control.statusChanges.pipe(
      map((status: FormControlStatus) => (status === 'INVALID' ? Object.values(control.errors) : [])),
      tap((invalidParams: InvalidParam[]) => (this.isValid = isEmpty(invalidParams))),
    );
  }
}
