import { ComponentFixture, TestBed } from '@angular/core/testing';

import { User } from '@admin-client/user-shared';
import { createStateResource, StateResource } from '@alfa-client/tech-shared';
import { dispatchEventFromFixture, getDebugElementFromFixtureByCss, mock, Mock } from '@alfa-client/test-utils';
import { ButtonWithSpinnerComponent } from '@ods/component';
import { cold } from 'jest-marbles';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import { getDataTestIdAttributeOf } from '../../../../../../tech-shared/test/data-test';
import { createUser } from '../../../../../user-shared/test/user';
import { UserFormService } from '../user.formservice';
import { UserFormSaveButtonComponent } from './user-form-save-button.component';

describe('UserFormSaveButtonComponent', () => {
  let component: UserFormSaveButtonComponent;
  let fixture: ComponentFixture<UserFormSaveButtonComponent>;

  let formService: Mock<UserFormService>;

  const saveButton: string = getDataTestIdAttributeOf('save-button');

  beforeEach(async () => {
    formService = <any>{
      ...mock(UserFormService),
      submit: jest.fn(),
    };

    await TestBed.configureTestingModule({
      declarations: [UserFormSaveButtonComponent, MockComponent(ButtonWithSpinnerComponent)],
      providers: [{ provide: UserFormService, useValue: formService }],
    }).compileComponents();

    fixture = TestBed.createComponent(UserFormSaveButtonComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('component', () => {
    describe('submit', () => {
      const userStateResource: StateResource<User> = createStateResource(createUser());

      beforeEach(() => {
        formService.submit.mockReturnValue(of(userStateResource));
      });

      it('should call formService submit', () => {
        component.submit();

        expect(formService.submit).toHaveBeenCalled();
      });

      it('should set submitState$', () => {
        component.submit();

        expect(component.submitStateResource$).toBeObservable(cold('(a|)', { a: userStateResource }));
      });
    });
  });

  describe('template', () => {
    describe('button save', () => {
      describe('input', () => {
        it('should be set', () => {
          const stateResource: StateResource<User> = createStateResource(createUser());
          component.submitStateResource$ = of(stateResource);

          fixture.detectChanges();

          expect(getDebugElementFromFixtureByCss(fixture, saveButton).componentInstance.stateResource).toEqual(stateResource);
        });
      });

      describe('output', () => {
        it('should call submit', () => {
          component.submit = jest.fn();

          dispatchEventFromFixture(fixture, saveButton, 'clickEmitter');

          expect(component.submit).toHaveBeenCalled();
        });
      });
    });
  });
});
