import { Directive, ElementRef, Input } from '@angular/core';

export const _verticalClasses: string[] = ['flex', 'flex-col'];
export const _horizontalClasses: string[] = ['flex', 'flex-wrap', 'gap-2'];

export enum BinaryFileListOrientation {
  HORIZONTAL = 'horizontal',
  VERTICAL = 'vertical',
}

@Directive({
  selector: '[binaryFileListOrientation]',
  standalone: true,
})
export class BinaryFileListOrientationDirective {
  @Input() set binaryFileListOrientation(orientation: BinaryFileListOrientation) {
    this.el.nativeElement.classList.add(...this._evaluateClasses(orientation));
  }

  constructor(private readonly el: ElementRef) {}

  _evaluateClasses(orientation: BinaryFileListOrientation): string[] {
    switch (orientation) {
      case BinaryFileListOrientation.VERTICAL:
        return _verticalClasses;
      case BinaryFileListOrientation.HORIZONTAL:
        return _horizontalClasses;
      default:
        return _horizontalClasses;
    }
  }
}
