/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BinaryFileResource } from '@alfa-client/binary-file-shared';
import { ToEmbeddedResourcesPipe, createStateResource } from '@alfa-client/tech-shared';
import { existsAsHtmlElement, getMockComponent, notExistsAsHtmlElement } from '@alfa-client/test-utils';
import { SpinnerComponent } from '@alfa-client/ui';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { faker } from '@faker-js/faker';
import { ResourceUri } from '@ngxp/rest';
import { AttachmentHeaderComponent, AttachmentWrapperComponent } from '@ods/system';
import { createBinaryFileListResource, createBinaryFileResource } from 'libs/binary-file-shared/test/binary-file';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { MockComponent } from 'ng-mocks';
import { BinaryFile2ContainerComponent } from '../binary-file2-container/binary-file2-container.component';
import { DownloadArchiveFileButtonContainerComponent } from '../download-archive-file-button-container/download-archive-file-button-container.component';
import { VerticalBinaryFileListComponent } from './vertical-binary-file-list.component';

describe('VerticalBinaryFileListComponent', () => {
  let component: VerticalBinaryFileListComponent;
  let fixture: ComponentFixture<VerticalBinaryFileListComponent>;

  const downloadArchiveFileButton: string = getDataTestIdOf('download-archive-file-button-container');
  const fileListHeader: string = getDataTestIdOf('file-list-header');

  const binaryFile: BinaryFileResource = createBinaryFileResource();

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        VerticalBinaryFileListComponent,
        ToEmbeddedResourcesPipe,
        MockComponent(AttachmentWrapperComponent),
        MockComponent(AttachmentHeaderComponent),
        MockComponent(BinaryFile2ContainerComponent),
        MockComponent(SpinnerComponent),
        MockComponent(DownloadArchiveFileButtonContainerComponent),
      ],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(VerticalBinaryFileListComponent);
    component = fixture.componentInstance;
    component.binaryFileListStateResource = createStateResource(createBinaryFileListResource([binaryFile]));
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('binary file component', () => {
    describe('should be called with', () => {
      it('file', () => {
        const comp: BinaryFile2ContainerComponent = getMockComponent(fixture, BinaryFile2ContainerComponent);

        expect(comp.file).toBe(binaryFile);
      });

      it('deletable', () => {
        const comp: BinaryFile2ContainerComponent = getMockComponent(fixture, BinaryFile2ContainerComponent);

        expect(comp.deletable).toBe(component.deletable);
      });

      it('downloadFileNamePrefix', () => {
        const comp: BinaryFile2ContainerComponent = getMockComponent(fixture, BinaryFile2ContainerComponent);

        expect(comp.downloadFileNamePrefix).toBe(component.downloadFileNamePrefix);
      });
    });
  });

  describe('attachment header', () => {
    it('should show header if there is title', () => {
      component.title = 'Title';

      fixture.detectChanges();

      existsAsHtmlElement(fixture, fileListHeader);
    });

    it('should show header if there is uri', () => {
      component.archiveDownloadUri = faker.internet.url();

      fixture.detectChanges();

      existsAsHtmlElement(fixture, fileListHeader);
    });

    it('should not show header if there is no uri or title', () => {
      component.title = '';

      fixture.detectChanges();

      notExistsAsHtmlElement(fixture, fileListHeader);
    });
  });

  describe('download archive button', () => {
    beforeEach(() => {
      component.title = 'Test title';
    });

    const downloadUri: ResourceUri = faker.internet.url();

    it('should be visible if uri exists', () => {
      component.archiveDownloadUri = downloadUri;

      fixture.detectChanges();

      existsAsHtmlElement(fixture, downloadArchiveFileButton);
    });

    it('should be hidden if uri is undefined', () => {
      component.archiveDownloadUri = undefined;

      fixture.detectChanges();

      notExistsAsHtmlElement(fixture, downloadArchiveFileButton);
    });

    describe('component should be called with', () => {
      beforeEach(() => {
        component.archiveDownloadUri = downloadUri;
        fixture.detectChanges();
      });

      it('downloadUri', () => {
        const comp: DownloadArchiveFileButtonContainerComponent = getMockComponent(
          fixture,
          DownloadArchiveFileButtonContainerComponent,
        );

        expect(comp.downloadUri).toBe(downloadUri);
      });
    });
  });
});
