/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { convertForDataTest, ConvertForDataTestPipe } from '@alfa-client/tech-shared';
import { getElementFromFixture, Mock, mock } from '@alfa-client/test-utils';
import { importProvidersFrom } from '@angular/core';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { Router, RouterModule } from '@angular/router';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { NavItemComponent } from './nav-item.component';

describe('NavItemComponent', () => {
  let component: NavItemComponent;
  let fixture: ComponentFixture<NavItemComponent>;

  const router: Mock<Router> = mock(Router);

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      imports: [NavItemComponent, ConvertForDataTestPipe],
      providers: [
        {
          provide: Router,
          useValue: router,
        },
        importProvidersFrom(RouterModule.forRoot([])),
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(NavItemComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('input', () => {
    describe('caption', () => {
      it('should set link text', () => {
        component.caption = 'Test caption';
        const testId: string = 'caption-' + convertForDataTest(component.caption);

        fixture.detectChanges();

        const captionElement: HTMLParagraphElement = getElementFromFixture(fixture, getDataTestIdOf(testId));
        expect(captionElement.innerHTML).toBe('Test caption');
      });
    });

    describe('path', () => {
      it('should set href', () => {
        component.path = 'pfad';
        const testId: string = 'link-path-' + convertForDataTest(component.path);

        fixture.detectChanges();

        const linkElement: HTMLAnchorElement = getElementFromFixture(fixture, getDataTestIdOf(testId));
        expect(linkElement).toHaveProperty('href');
      });
    });
  });

  describe('template', () => {
    describe('host element role attribute', () => {
      it('should be "menuitem"', () => {
        expect(fixture.nativeElement.getAttribute('role')).toBe('menuitem');
      });
    });
  });
});
