/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { CommandResource } from '@alfa-client/command-shared';
import { LoeschAnforderungResource, LoeschAnforderungService } from '@alfa-client/loesch-anforderung-shared';
import { StateResource, createEmptyStateResource } from '@alfa-client/tech-shared';
import { BasicDialogComponent, BasicDialogData, DialogService } from '@alfa-client/ui';
import { LoeschAnforderungLinkRel, VorgangWithEingangLinkRel, VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { Component, Input } from '@angular/core';
import { MatDialogRef } from '@angular/material/dialog';
import { Observable, filter, first, of } from 'rxjs';

@Component({
  selector: 'alfa-endgueltig-loeschen-button-container',
  templateUrl: './endgueltig-loeschen-button-container.component.html',
  styles: [':host {@apply empty:hidden}'],
})
export class EndgueltigLoeschenButtonContainerComponent {
  @Input() vorgang: VorgangWithEingangResource;
  @Input() showAsIconButton: boolean = false;

  commandStateResource$: Observable<StateResource<CommandResource>> = of(createEmptyStateResource<CommandResource>());
  loeschAnforderungResource$: Observable<StateResource<LoeschAnforderungResource>>;

  readonly vorgangWithEingangLinkRel = VorgangWithEingangLinkRel;
  readonly loeschAnforderungLinkRel = LoeschAnforderungLinkRel;

  dialogRef: MatDialogRef<BasicDialogComponent>;

  constructor(
    private loeschAnforderungService: LoeschAnforderungService,
    private dialogService: DialogService,
  ) {}

  ngOnInit(): void {
    this.commandStateResource$ = this.loeschAnforderungService.getEndgueltigLoeschenCommand();
    this.loeschAnforderungResource$ = this.loeschAnforderungService.getLoeschAnforderung();
  }

  public openEndgueltigLoeschenDialog(loeschAnforderungResource: StateResource<LoeschAnforderungResource>): void {
    const dialogRef: MatDialogRef<BasicDialogComponent> = this.dialogService.openBasic(this.createBasicDialogConfig());

    dialogRef
      .afterClosed()
      .pipe(
        first(),
        filter((response) => response === true),
      )
      .subscribe(() => this.endgueltigLoeschen(loeschAnforderungResource));
  }

  createBasicDialogConfig(): BasicDialogData {
    return {
      title: 'Möchten Sie den Vorgang endgültig löschen?',
      message: 'Diese Aktion kann nicht widerrufen werden.',
      okText: 'Endgültig löschen',
      okSvgIcon: 'delete_finally',
    };
  }

  endgueltigLoeschen(loeschAnforderungResource: StateResource<LoeschAnforderungResource>): void {
    this.loeschAnforderungService.endgueltigLoeschen(loeschAnforderungResource.resource);
  }
}
