/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { OrganisationsEinheitResourceService } from '@alfa-client/organisations-einheit-shared';
import { createEmptyStateResource, StateResource } from '@alfa-client/tech-shared';
import { OrganisationsEinheitResource } from '@alfa-client/zustaendige-stelle-shared';
import { CommonModule } from '@angular/common';
import { Component, inject, Input, OnInit } from '@angular/core';
import { ResourceUri } from '@ngxp/rest';
import { Observable, of } from 'rxjs';
import { OrganisationsEinheitListItemComponent } from './organisations-einheit-list-item/organisations-einheit-list-item.component';

@Component({
  selector: 'alfa-organisations-einheit-list-item-container',
  standalone: true,
  imports: [CommonModule, OrganisationsEinheitListItemComponent],
  providers: [OrganisationsEinheitResourceService],
  templateUrl: './organisations-einheit-list-item-container.component.html',
})
export class OrganisationsEinheitListItemContainerComponent implements OnInit {
  private organisationsEinheitResourceService: OrganisationsEinheitResourceService = inject(OrganisationsEinheitResourceService);

  @Input() organisationsEinheitResourceUri: ResourceUri;

  organisationsEinheitStateResource$: Observable<StateResource<OrganisationsEinheitResource>> =
    of(createEmptyStateResource<OrganisationsEinheitResource>());

  ngOnInit() {
    this.organisationsEinheitStateResource$ = this.organisationsEinheitResourceService.getOrganisationsEinheit(
      this.organisationsEinheitResourceUri,
    );
  }
}
