/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { Direction } from '@alfa-client/postfach-shared';
import { FormatDateWithTimePipe, HasLinkPipe } from '@alfa-client/tech-shared';
import { getElementFromFixture } from '@alfa-client/test-utils';
import { registerLocaleData } from '@angular/common';
import localeDe from '@angular/common/locales/de';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { createPostfachMailResource } from 'libs/postfach-shared/test/postfach';
import { PostfachMailDateComponent } from './postfach-mail-date.component';

registerLocaleData(localeDe);

describe('PostfachMailDateComponent', () => {
  let component: PostfachMailDateComponent;
  let fixture: ComponentFixture<PostfachMailDateComponent>;

  const sentAt: string = '[data-test-id="mail-sent-at"]';
  const createdAt: string = '[data-test-id="mail-created-at"]';

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      imports: [HasLinkPipe, FormatDateWithTimePipe],
      declarations: [PostfachMailDateComponent],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(PostfachMailDateComponent);
    component = fixture.componentInstance;
    component.postfachMail = createPostfachMailResource();
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('on outgoing mail', () => {
    beforeEach(() => {
      component.postfachMail = { ...createPostfachMailResource(), direction: Direction.OUT };
      fixture.detectChanges();
    });

    it('should show sentAt', () => {
      const element = getElementFromFixture(fixture, sentAt);

      expect(element).toBeInstanceOf(HTMLElement);
    });

    it('should hide createdAt', () => {
      const element = getElementFromFixture(fixture, createdAt);

      expect(element).not.toBeInstanceOf(HTMLElement);
    });
  });

  describe('in incoming mail', () => {
    beforeEach(() => {
      component.postfachMail = { ...createPostfachMailResource(), direction: Direction.IN };
      fixture.detectChanges();
    });

    it('should show createdAt', () => {
      const element = getElementFromFixture(fixture, createdAt);

      expect(element).toBeInstanceOf(HTMLElement);
    });

    it('should hide sentAt', () => {
      const element = getElementFromFixture(fixture, sentAt);

      expect(element).not.toBeInstanceOf(HTMLElement);
    });
  });
});
