/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { createStateResource, StateResource } from '@alfa-client/tech-shared';
import { Mock, mock, useFromMock } from '@alfa-client/test-utils';
import { UserProfileResource } from '@alfa-client/user-profile-shared';
import { Store } from '@ngrx/store';
import { createUserProfileResource } from 'libs/user-profile-shared/test/user-profile';
import {
  createUserSettings,
  createUserSettingsResource,
} from 'libs/user-settings-shared/test/user-settings';
import { Subject } from 'rxjs';
import { UserSettings, UserSettingsResource } from '../user-settings.model';
import * as UserSettingsActions from './user-settings.actions';
import { UserSettingsFacade } from './user-settings.facade';

describe('UserSettingsFacade', () => {
  const store: Mock<Store> = mock(Store);
  let facade: UserSettingsFacade;
  let userSettingsSubj: Subject<StateResource<UserSettingsResource>>;

  beforeEach(() => {
    userSettingsSubj = new Subject();
    store.select.mockReturnValue(userSettingsSubj);

    facade = new UserSettingsFacade(useFromMock(store));
  });

  describe('loadUserSettings', () => {
    it('should dispatch "loadUserSettings"', () => {
      const currentUser: UserProfileResource = createUserProfileResource();

      facade.loadUserSettings(currentUser);

      expect(store.dispatch).toHaveBeenCalledWith(
        UserSettingsActions.loadUserSettings({ currentUser }),
      );
    });
  });

  describe('getUserSettings', () => {
    it('should return selected value', (done) => {
      const expected: StateResource<UserSettingsResource> = createStateResource(
        createUserSettingsResource(),
      );

      facade.getUserSettings().subscribe((userSettings) => {
        expect(userSettings).toBe(expected);
        done();
      });

      userSettingsSubj.next(expected);
    });
  });

  describe('setUserSettings', () => {
    it('should dispatch "setUserSettings"', () => {
      const userSettings: UserSettings = createUserSettings();

      facade.setUserSettings(userSettings);

      expect(store.dispatch).toHaveBeenCalledWith(
        UserSettingsActions.setUserSettings({ userSettings }),
      );
    });
  });
});
