/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { notExistsAsHtmlElement } from '@alfa-client/test-utils';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { ExpansionPanelComponent } from 'libs/ui/src/lib/ui/expansion-panel/expansion-panel.component';
import { createEingang } from 'libs/vorgang-shared/test/vorgang';
import { MockComponent } from 'ng-mocks';
import { VorgangDetailFormDataTableComponent } from '../vorgang-detail-form-data-table/vorgang-detail-form-data-table.component';
import { VorgangDetailAntragDataComponent } from './vorgang-detail-antrag-data.component';
import { VorgangDetailEingangHeaderComponent } from './vorgang-detail-eingang-header/vorgang-detail-eingang-header.component';

describe('VorgangDetailAntragDataComponent', () => {
  let component: VorgangDetailAntragDataComponent;
  let fixture: ComponentFixture<VorgangDetailAntragDataComponent>;

  const formulardatenPanelSelector: string = getDataTestIdOf('antragdaten-panel');
  const headerPanelSelector: string = getDataTestIdOf('header-panel');
  const antragdaten: string = getDataTestIdOf('antragdaten');
  const antragstellerOtherDataTableSelector: string = getDataTestIdOf(
    'antragsteller-other-data-table',
  );

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        VorgangDetailAntragDataComponent,
        MockComponent(ExpansionPanelComponent),
        MockComponent(VorgangDetailEingangHeaderComponent),
        MockComponent(VorgangDetailFormDataTableComponent),
      ],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(VorgangDetailAntragDataComponent);
    component = fixture.componentInstance;
    component.eingang = null;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('Formulardaten Panel ', () => {
    it('should NOT be visible', () => {
      const formulardatenPanel = fixture.nativeElement.querySelector(formulardatenPanelSelector);

      expect(formulardatenPanel).not.toBeInstanceOf(HTMLElement);
    });

    it('should be visible if data has children', () => {
      component.eingang = createEingang();
      fixture.detectChanges();

      const formulardatenPanel = fixture.nativeElement.querySelector(formulardatenPanelSelector);

      expect(formulardatenPanel).toBeInstanceOf(HTMLElement);
    });
  });

  describe('Eingang Header Panel', () => {
    it('should NOT be visible', () => {
      const headerPanel = fixture.nativeElement.querySelector(headerPanelSelector);

      expect(headerPanel).not.toBeInstanceOf(HTMLElement);
    });

    it('should be visible if data has children', () => {
      component.eingang = createEingang();
      fixture.detectChanges();

      const headerPanel = fixture.nativeElement.querySelector(headerPanelSelector);

      expect(headerPanel).toBeInstanceOf(HTMLElement);
    });
  });

  describe('Formulardaten Data Table', () => {
    it('should NOT be visible', () => {
      const formulardatenDataTable = fixture.nativeElement.querySelector(antragdaten);

      expect(formulardatenDataTable).not.toBeInstanceOf(HTMLElement);
    });

    it('should be visible if data has children', () => {
      component.eingang = createEingang();
      component.antragsData = {};
      fixture.detectChanges();

      const formulardatenDataTable = fixture.nativeElement.querySelector(antragdaten);

      expect(formulardatenDataTable).toBeInstanceOf(HTMLElement);
    });
  });

  describe('Antragsteller Other Data Table', () => {
    it('should NOT be visible', () => {
      const antragstellerOtherDataTable = fixture.nativeElement.querySelector(
        antragstellerOtherDataTableSelector,
      );

      expect(antragstellerOtherDataTable).not.toBeInstanceOf(HTMLElement);
    });

    it('should proceed without antragsteller', () => {
      component.eingang = { ...createEingang(), antragsteller: null };
      fixture.detectChanges();

      notExistsAsHtmlElement(fixture, antragstellerOtherDataTableSelector);
    });

    it('should be visible if data has children', () => {
      component.eingang = createEingang();
      component.eingang.antragsteller.otherData = new Map();
      fixture.detectChanges();

      const antragstellerOtherDataTable = fixture.nativeElement.querySelector(
        antragstellerOtherDataTableSelector,
      );

      expect(antragstellerOtherDataTable).toBeInstanceOf(HTMLElement);
    });
  });
});
