/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { createEmptyStateResource, StateResource } from '@alfa-client/tech-shared';
import { VorgangHeaderLinkRel, VorgangResource } from '@alfa-client/vorgang-shared';
import { WiedervorlageListResource, WiedervorlageService } from '@alfa-client/wiedervorlage-shared';
import { Component, Input, OnChanges } from '@angular/core';
import { Observable, of } from 'rxjs';

@Component({
  selector: 'alfa-wiedervorlage-list-in-vorgang-container',
  templateUrl: './wiedervorlage-list-in-vorgang-container.component.html',
  styleUrls: ['./wiedervorlage-list-in-vorgang-container.component.scss'],
})
export class WiedervorlageListInVorgangContainerComponent implements OnChanges {
  @Input() vorgangStateResource: StateResource<VorgangResource>;

  wiedervorlagenStateResource$: Observable<StateResource<WiedervorlageListResource>> =
    of(createEmptyStateResource<WiedervorlageListResource>());

  readonly vorgangLinkRel = VorgangHeaderLinkRel;

  constructor(private wiedervorlageService: WiedervorlageService) {}

  ngOnChanges(): void {
    this.reloadWiedervorlageListOnVorgangReload();
    this.wiedervorlagenStateResource$ = this.wiedervorlageService.getWiedervorlageListByGivenVorgang(
      this.vorgangStateResource.resource,
    );
  }

  reloadWiedervorlageListOnVorgangReload(): void {
    if (this.vorgangStateResource.reload) {
      this.wiedervorlageService._setWiedervorlageListReload();
    }
  }
}
