/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BinaryFileAttachmentContainerComponent } from '@alfa-client/binary-file';
import { createStateResource, StateResource } from '@alfa-client/tech-shared';
import { Mock, mock, useFromMock } from '@alfa-client/test-utils';
import { DateEditorComponent, OzgcloudTextEditorComponent, TextAreaEditorComponent } from '@alfa-client/ui';
import { WiedervorlageListResource, WiedervorlageResource, WiedervorlageService } from '@alfa-client/wiedervorlage-shared';
import { SimpleChanges } from '@angular/core';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { ReactiveFormsModule, UntypedFormBuilder } from '@angular/forms';
import { createWiedervorlageListResource, createWiedervorlageResource } from 'libs/wiedervorlage-shared/test/wiedervorlage';
import { MockComponent } from 'ng-mocks';
import { MultiFileUploadComponent } from '../../../../../../binary-file/src/lib/multi-file-upload/multi-file-upload.component';
import { SubmitWiedervorlageButtonComponent } from '../../../submit-wiedervorlage-button/submit-wiedervorlage-button.component';
import { WiedervorlageFormComponent } from './wiedervorlage-form.component';
import { WiedervorlageFormService } from './wiedervorlage.formservice';

describe('WiedervorlageFormComponent', () => {
  let component: WiedervorlageFormComponent;
  let fixture: ComponentFixture<WiedervorlageFormComponent>;

  const formService = new WiedervorlageFormService(new UntypedFormBuilder(), useFromMock(mock(WiedervorlageService)));
  const wiedervorlageService: Mock<WiedervorlageService> = mock(WiedervorlageService);
  const wiedervorlage: WiedervorlageResource = createWiedervorlageResource();
  const wiedervorlaeListStateResource: StateResource<WiedervorlageListResource> = createStateResource(
    createWiedervorlageListResource(),
  );

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        WiedervorlageFormComponent,
        MockComponent(DateEditorComponent),
        MockComponent(OzgcloudTextEditorComponent),
        MockComponent(TextAreaEditorComponent),
        MockComponent(BinaryFileAttachmentContainerComponent),
        MockComponent(SubmitWiedervorlageButtonComponent),
        MockComponent(MultiFileUploadComponent),
      ],
      imports: [ReactiveFormsModule],
      providers: [
        {
          provide: WiedervorlageFormService,
          useValue: formService,
        },
        {
          provide: WiedervorlageService,
          useValue: wiedervorlageService,
        },
      ],
    });
  });

  beforeEach(() => {
    formService.patch = jest.fn();

    fixture = TestBed.createComponent(WiedervorlageFormComponent);
    component = fixture.componentInstance;
    component.wiedervorlageListStateResource = wiedervorlaeListStateResource;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('ngOnChanges', () => {
    const simpleChanges: SimpleChanges = <any>{ wiedervorlage };

    beforeEach(() => {
      component.wiedervorlage = wiedervorlage;
      component.patchWiedervorlage = jest.fn();
    });

    it('should call patchWiedervorlage', () => {
      component.ngOnChanges(simpleChanges);

      expect(component.patchWiedervorlage).toHaveBeenCalled();
    });
  });

  describe('patch wiedervorlage', () => {
    it('should NOT patch by formservice', () => {
      component.wiedervorlage = null;

      component.patchWiedervorlage();

      expect(formService.patch).not.toHaveBeenCalled();
    });

    it('should patch by formservice', () => {
      component.wiedervorlage = wiedervorlage;

      component.patchWiedervorlage();

      expect(formService.patch).toHaveBeenCalledWith(wiedervorlage);
    });
  });
});
